@@ -53,7 +53,7 @@ def read_auto(fileName, inferOnly=False, verbose=True):
     if verbose:
         print skippedN    
     if info['names'] is not None: 
-        del info['names']
+        del info['names'], info['num_col']
         return read_csv(**info)
         #skippedN.columns = skippedN.ix[0,:]
         #skippedN = skippedN.ix[1:,:] 
